@@ -1,9 +1,6 @@
-# Mikes Package
+# LGRID & EGRID
 import os
-from tkinter import *
-
-__version__ = '1.0.0b'
-__author__ = 'Michael Mulvey'
+from tkinter import Entry, Label
 
 
 def lgrid(self, text, gridcol, gridrow, **args):
@@ -16,3 +13,12 @@ def lgrid(self, text, gridcol, gridrow, **args):
     0,0 is the column and row to place them"""
     lbl = Label(self, text=text)
     lbl.grid(column=gridcol, row=gridrow, **args)
+
+
+def egrid(self, col, row, *args, **kwarg):
+    """ Entry Maker
+    Example:
+    egrid(root,1,0)
+    """
+    e1 = Entry(self)
+    e1.grid(column=col, row=row)
